# This is an AWS SQS module. The processed messages will be sent to SNS topic by other services.
# SQS queue subscribe to this SNS topic to queue the messages for further processing.
# In the architecture, an HTTP endpoint shall read data from SQS for further processing in most of the cases.

import json
import boto3

def read_from_sqs_queue(region, queue_url, max_number_messages = 10, timeout_secs = 20, delete_on_read = True):
    sqs_client = boto3.client('sqs', region_name = region)  

    # Receive messages from the queue
    response = sqs_client.receive_message(
        QueueUrl=queue_url,
        MaxNumberOfMessages = max_number_messages,  # Maximum number of messages to retrieve
        WaitTimeSeconds = timeout_secs,      # Long polling: Wait up to 20 seconds for messages
    )

    if True == delete_on_read:
        if 'Messages' in response:
            # Process each message
            for message in response['Messages']:
                # Delete the message from the queue
                sqs_client.delete_message(
                    QueueUrl=queue_url,
                    ReceiptHandle=message['ReceiptHandle']
                )

    return response


# This is an AWS SNS module. The processed MQTT messages will be sent to SNS topic by other services.
# There will be an different subscribers to SNS to queue/notify the messages for further processing.
# In the architecture, an HTTP endpoint shall read data from SQS for further processing in most of the cases.

import json
import boto3

def post_to_sns_topic(region, arn, key, value, topic):
    sns_client = boto3.client('sns', region_name = region)  # Replace 'your_region' with your AWS region

    message = {
        "key": key,
        "value" : value,
        "topic" : topic
    }
    json_data = json.dumps(message)
    # Publish the message to the SNS topic
    response = sns_client.publish(
        TopicArn = arn,
        Message = json_data
    )
    return response



import mysql.connector
from typing import List, Tuple

"""""
@dataclass
class mysql:
    username: String
    password: String
    host: String
    database_name: String
    raise_on_warnings: Bool
"""""
class MYSQL_DB_CLIENT:
    def __init__(self, username, password, hostname, database_name, raise_on_warnings = True) -> None:
        self.username = username
        self.password =password
        self.hostname = hostname
        self.database_name = database_name
        self.raise_on_warnings = raise_on_warnings
        self.cursor = None 

    def db_connect(self) -> None:
        self.connection = mysql.connector.connect(
                        user = self.username,
                        password = self.password,
                        host = self.hostname,
                        database = self.database_name,
                        raise_on_warnings = self.raise_on_warnings
                    )
        self.cursor = self.connection.cursor()

    def db_execute_query(self, query) -> None:
        self.cursor.execute(query)
        print(f"In DB CLass execute query {query}")
        #self.connection.commit()

    def db_read_result(self) -> List[Tuple]:
        result = self.cursor.fetchall()
        print(f'Read Result {result}')
        return result

    def db_read_sensor_id_from_heimdall_memory(self, customer_name, site_name, building_name, floor_position, type_id, sensor_name) -> int:
        query =  """
        SELECT sensors.sensor_id
        FROM sensors
        JOIN floors ON sensors.floor_id = floors.floor_id
        JOIN buildings ON floors.building_id = buildings.building_id
        JOIN sites ON buildings.site_id = sites.site_id
        JOIN customers ON sites.customer_id = customers.customer_id
        JOIN sensor_type ON sensors.type_id = sensor_type.type_id
        WHERE customers.customer_name = %s
        AND sites.site_name = %s
        AND buildings.building_name = %s
        AND floors.floor_position = %s
        AND sensor_type.type_id = %s
        AND sensors.sensor_name = %s
        """
        # Execute the query
        self.cursor.execute(query, (customer_name, site_name, building_name, floor_position, type_id, sensor_name))
        result = self.cursor.fetchone()
        if result:
            print(f"MYSQL LOGS: Result --> {result}")
            #sensor_id = result['sensor_id']
        
        return result



# setup.py

from setuptools import setup, find_packages

packs= find_packages()
print(packs)

setup(
    name='heimdall_tools',
    version='0.1.2',
    packages=find_packages(),
    #packages=['heimdall_tools'],
    install_requires=[
        'boto3',
        'mysql-connector-python',
        # Add any other dependencies here
    ],
    author='Robin Thomas',
    author_email='robin@clockhash.com',
    description='Custom package including all modules required for my application',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/your_username/your_package',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    license='MIT',
)
